`pyramid_foundation <http://github.com/ppinette/pyramid_foundation>`_
============================================================================

This package provides a Pyramid scaffold which includes `Zurb Foundation <http://foundation.zurb.com/>`_

pyramid_foundation is intended to extend other scaffolds such as starter or alchemy. Using it alone will not create a Pyramid project.


Getting Started
---------------

    $ pcreate -s <scaffold> -s pyramid_foundation <project_name>

Your newly created project will have the Foundation files located in Project/package/static/ 

Additionally, mytemplate.pt has been modified to include the Foundation CSS and JS along with the standard basic introduction to Foundation. 

Currently, pyramid_foundation provides the full foundation.css as well as the per-component files. Future support for SASS/Compass is planned. 
